@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: parsec
-version: 3.1.1
-id: parsec-3.1.1-f737418bc255d829c47b208a553987bf
+version: 3.1.3
+id: parsec-3.1.3-fb970d7908f363dfef34b141200235e6
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: Antoine Latter <aslatter@gmail.com>
 stability:
 homepage: http://www.cs.uu.nl/~daan/parsec.html
 package-url:
+synopsis: Monadic parser combinators
 description: Parsec is designed from scratch as an industrial-strength parser
              library.  It is simple, safe, well documented (on the package
              homepage), has extensive libraries and good error messages,
@@ -20,10 +21,11 @@ author: Daan Leijen <daan@microsoft.com>, Paolo Martini <paolo@nemail.it>
 pkgpath: devel/hs-parsec
 exposed: True
 exposed-modules: Text.Parsec Text.Parsec.String
-                 Text.Parsec.ByteString Text.Parsec.ByteString.Lazy Text.Parsec.Pos
-                 Text.Parsec.Error Text.Parsec.Prim Text.Parsec.Char
-                 Text.Parsec.Combinator Text.Parsec.Token Text.Parsec.Expr
-                 Text.Parsec.Language Text.Parsec.Perm Text.ParserCombinators.Parsec
+                 Text.Parsec.ByteString Text.Parsec.ByteString.Lazy Text.Parsec.Text
+                 Text.Parsec.Text.Lazy Text.Parsec.Pos Text.Parsec.Error
+                 Text.Parsec.Prim Text.Parsec.Char Text.Parsec.Combinator
+                 Text.Parsec.Token Text.Parsec.Expr Text.Parsec.Language
+                 Text.Parsec.Perm Text.ParserCombinators.Parsec
                  Text.ParserCombinators.Parsec.Char
                  Text.ParserCombinators.Parsec.Combinator
                  Text.ParserCombinators.Parsec.Error
@@ -34,21 +36,23 @@ exposed-modules: Text.Parsec Text.Parsec.String
                  Text.ParserCombinators.Parsec.Prim
                  Text.ParserCombinators.Parsec.Token
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/parsec-3.1.1
-library-dirs: /usr/local/lib/ghc/parsec-3.1.1
-hs-libraries: HSparsec-3.1.1
+trusted: False
+import-dirs: /usr/local/lib/ghc/parsec-3.1.3
+library-dirs: /usr/local/lib/ghc/parsec-3.1.3
+hs-libraries: HSparsec-3.1.3
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-912d55d387093f740e3bcd2ffbf1dd83
-         bytestring-0.9.1.10-e7cebdd905566e960c42140389871ec1
-         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
+depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
+         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
+         text-0.11.2.3-6d44323283fc0f3935743a72b4424942
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-parsec-3.1.1/html/parsec.haddock
-haddock-html: /usr/local/share/doc/hs-parsec-3.1.1/html
+haddock-interfaces: /usr/local/share/doc/hs-parsec-3.1.3/html/parsec.haddock
+haddock-html: /usr/local/share/doc/hs-parsec-3.1.3/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
